require 'spec_helper'

describe Gris::Middleware::JsonWebTokenDecoder do
  let(:hmac_secret) { 'https://www.youtube.com/watch?v=F5bAa6gFvLs' }
  subject { described_class.new(app) }

  let(:token) do
    JWT.encode payload_data, hmac_secret, 'HS256'
  end

  let(:payload_data) do
    {
      'carl' => 'So its a code breaker?',
      'marty' => 'No its the code breaker.'
    }
  end

  let(:app) { ->(env) { [200, env, env] } }

  context 'with HTTP_AUTHORIZATION header' do
    before do
      Gris.secrets.hmac_secret = hmac_secret
    end

    it "decodes token and sets env['GRIS_JWT_PAYLOAD']" do
      status, _, env = subject.call('HTTP_AUTHORIZATION' => "Bearer: #{token}")
      expect(env['GRIS_JWT_PAYLOAD'].first).to eql payload_data
      expect(status).to eq(200)
    end
  end

  context 'without HTTP_AUTHORIZATION header' do
    it "does not set env['GRIS_JWT_PAYLOAD']" do
      status, _, env = subject.call({})
      expect(env['GRIS_JWT_PAYLOAD']).to be_nil
      expect(status).to eq(200)
    end
  end
end
